@@ -59,9 +59,6 @@ struct r_type_pairstring_string_tag{} ;
  */
 struct r_type_pairstring_generic_tag{} ;
 
-struct r_type_int64_tag{} ;
-struct r_type_uint64_tag{} ;
-
 /**
  * R type trait. Helps wrap.
  */
@@ -96,6 +93,13 @@ template<> struct r_type_traits<unsigned int>{ typedef r_type_primitive_tag r_ca
 template<> struct r_type_traits<float>{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits<const char*>{ typedef r_type_string_tag r_category ; } ;
 
+/* long */
+template<> struct r_type_traits<long>{ typedef r_type_primitive_tag r_category ; } ;
+template<> struct r_type_traits< std::pair<const std::string,long> >{ typedef r_type_primitive_tag r_category ; } ;
+
+/* unsigned long */
+template<> struct r_type_traits<unsigned long>{ typedef r_type_primitive_tag r_category ; } ;
+template<> struct r_type_traits< std::pair<const std::string,unsigned long> >{ typedef r_type_primitive_tag r_category ; } ;
 
 /* long double */
 template<> struct r_type_traits<long double>{ typedef r_type_primitive_tag r_category ; } ;
@@ -108,7 +112,7 @@ template<> struct r_type_traits< std::pair<const std::string,short> >{ typedef r
 /* unsigned short */
 template<> struct r_type_traits<unsigned short>{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits< std::pair<const std::string,unsigned short> >{ typedef r_type_primitive_tag r_category ; } ;
-                                                    
+
 /* std::complex<double> */
 template<> struct r_type_traits< std::complex<double> >{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits< std::pair<const std::string,std::complex<double> > >{ typedef r_type_primitive_tag r_category ; } ;
@@ -118,27 +122,12 @@ template<> struct r_type_traits< std::complex<float> >{ typedef r_type_primitive
 template<> struct r_type_traits< std::pair<const std::string,std::complex<float> > >{ typedef r_type_primitive_tag r_category ; } ;
 
 /* long long int */
-// #ifdef RCPP_HAS_LONG_LONG_TYPES
-// template<> struct r_type_traits<rcpp_long_long_type>{ typedef r_type_primitive_tag r_category ; } ;
-// template<> struct r_type_traits< std::pair<const std::string,rcpp_long_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
-// template<> struct r_type_traits<rcpp_ulong_long_type>{ typedef r_type_primitive_tag r_category ; } ;
-// template<> struct r_type_traits< std::pair<const std::string,rcpp_ulong_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
-// #endif
-
-// /* long */
-// template<> struct r_type_traits<long>{ typedef r_type_primitive_tag r_category ; } ;
-// template<> struct r_type_traits< std::pair<const std::string,long> >{ typedef r_type_primitive_tag r_category ; } ;
-// 
-// /* unsigned long */
-// template<> struct r_type_traits<unsigned long>{ typedef r_type_primitive_tag r_category ; } ;
-// template<> struct r_type_traits< std::pair<const std::string,unsigned long> >{ typedef r_type_primitive_tag r_category ; } ;
-
-
-
-
-template<> struct r_type_traits<int64_t>{ typedef r_type_int64_tag r_category; } ;
-template<> struct r_type_traits<uint64_t>{ typedef r_type_uint64_tag r_category ; } ;
-
+#ifdef RCPP_HAS_LONG_LONG_TYPES
+template<> struct r_type_traits<rcpp_long_long_type>{ typedef r_type_primitive_tag r_category ; } ;
+template<> struct r_type_traits< std::pair<const std::string,rcpp_long_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
+template<> struct r_type_traits<rcpp_ulong_long_type>{ typedef r_type_primitive_tag r_category ; } ;
+template<> struct r_type_traits< std::pair<const std::string,rcpp_ulong_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
+#endif
 
 } // traits
 } // Rcpp
